% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/eppoFindeR-package.R
\docType{package}
\name{eppoFindeR-package}
\alias{eppoFindeR}
\alias{eppoFindeR-package}
\title{eppoFindeR: Interface to the EPPO Database and Public APIs}
\description{
\if{html}{\figure{logo.png}{options: style='float: right' alt='logo' width='120'}}

Provides an interface to the public APIs of the European and Mediterranean Plant Protection Organization (EPPO) database. It enables users to retrieve EPPO data by accessing specific services and datasets. The package also includes utilities for data wrangling, including the integration of taxonomy with rank information. See \url{https://data.eppo.int/apis/} for more details.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://openefsa.github.io/eppoFindeR/}
  \item Report bugs at \url{https://github.com/openefsa/eppoFindeR/issues}
}

}
\author{
\strong{Maintainer}: Luca Belmonte \email{luca.belmonte@efsa.europa.eu} (\href{https://orcid.org/0000-0002-7977-9170}{ORCID})

Authors:
\itemize{
  \item Lorenzo Copelli (\href{https://orcid.org/0009-0002-4305-065X}{ORCID})
  \item Dayana Stephanie Buzle (\href{https://orcid.org/0009-0003-2990-7431}{ORCID})
  \item Rafael Vieira (\href{https://orcid.org/0009-0009-0289-5438}{ORCID})
  \item Agata Kaczmarek (\href{https://orcid.org/0000-0002-7463-5821}{ORCID})
}

}
\keyword{internal}
